summaryrefslogtreecommitdiff
path: root/lib/util.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util.php')
-rw-r--r--lib/util.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/util.php b/lib/util.php
index 1e7834057..cedb70873 100644
--- a/lib/util.php
+++ b/lib/util.php
@@ -1,7 +1,7 @@
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2008, 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -54,9 +54,9 @@ function common_init_language()
$language = common_language();
// So we don't have to make people install the gettext locales
$locale_set = common_init_locale($language);
- bindtextdomain("laconica", common_config('site','locale_path'));
- bind_textdomain_codeset("laconica", "UTF-8");
- textdomain("laconica");
+ bindtextdomain("statusnet", common_config('site','locale_path'));
+ bind_textdomain_codeset("statusnet", "UTF-8");
+ textdomain("statusnet");
setlocale(LC_CTYPE, 'C');
if(!$locale_set) {
common_log(LOG_INFO,'Language requested:'.$language.' - locale could not be set:',__FILE__);
@@ -1319,7 +1319,7 @@ function common_cache_key($extra)
$base_key = common_keyize(common_config('site', 'name'));
}
- return 'laconica:' . $base_key . ':' . $extra;
+ return 'statusnet:' . $base_key . ':' . $extra;
}
function common_keyize($str)
@@ -1382,7 +1382,7 @@ function common_shorten_url($long_url)
$curlh = curl_init();
curl_setopt($curlh, CURLOPT_CONNECTTIMEOUT, 20); // # seconds to wait
- curl_setopt($curlh, CURLOPT_USERAGENT, 'Laconica');
+ curl_setopt($curlh, CURLOPT_USERAGENT, 'StatusNet');
curl_setopt($curlh, CURLOPT_RETURNTRANSFER, true);
switch($svc) {
@@ -1,7 +1,7 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2008, 2009, Control Yourself, Inc.
+ * StatusNet - the distributed open-source microblogging tool
+ * Copyright (C) 2008, 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify